@@ -376,7 +376,7 @@ gedit_document_new (void)
   	
 	document->priv->untitled_number = gedit_document_get_untitled_number ();
 	g_return_val_if_fail (document->priv->untitled_number > 0, NULL);
-		
+	
 	return document;
 }
 
@@ -723,9 +723,9 @@ gedit_document_load (GeditDocument        *doc,
 		     const GeditEncoding  *encoding,
 		     GError              **error)
 {
-	char* file_contents;
+	gchar* file_contents;
 	GnomeVFSResult res;
-   	gsize file_size;
+   	gint file_size;
 	GtkTextIter iter, end;
 	
 	gedit_debug (DEBUG_DOCUMENT, "File to load: %s", uri);
@@ -733,7 +733,7 @@ gedit_document_load (GeditDocument        *doc,
 	g_return_val_if_fail (doc != NULL, FALSE);
 	g_return_val_if_fail (uri != NULL, FALSE);
 
-	res = eel_read_entire_file (uri, &file_size, &file_contents);
+	res = gnome_vfs_read_entire_file (uri, &file_size, &file_contents);
 
 	gedit_debug (DEBUG_DOCUMENT, "End reading %s (result: %s)", uri, gnome_vfs_result_to_string (res));
 	
@@ -2277,6 +2277,9 @@ gedit_document_set_language (GeditDocument *doc, GtkSourceLanguage *lang)
 
 	gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (doc), lang);
 
+	if (lang != NULL)
+		gedit_language_init_tag_styles (lang);
+
 	if (doc->priv->uri != NULL)
 	{
 		gchar *lang_id = NULL;
