@@ -106,6 +106,7 @@ static void gedit_mdi_child_changed_handler (BonoboMDI *mdi, BonoboMDIChild *old
 static void gedit_mdi_child_state_changed_handler (GeditMDIChild *child);
 
 static void gedit_mdi_set_active_window_undo_redo_verbs_sensitivity (BonoboMDI *mdi);
+static void gedit_mdi_set_active_window_find_verbs_sensitivity (BonoboMDI *mdi);
 
 static void gedit_mdi_app_destroy_handler (BonoboMDI *mdi, BonoboWindow *window);
 
@@ -118,8 +119,6 @@ static void gedit_mdi_view_menu_item_toggled_handler (
 static void add_languages_menu (BonoboMDI *mdi, BonoboWindow *win);
 static void gedit_mdi_update_languages_menu (BonoboMDI *mdi);
 
-static void gedit_mdi_update_encoding_status_bar (BonoboMDI *mdi);
-
 static GQuark window_prefs_id = 0;
 
 static GeditWindowPrefs *gedit_window_prefs_new 		(void);
@@ -245,7 +244,27 @@ open_button_key_pressed_cb (GtkWidget *widget,
 	return FALSE;
 }
 
+static void
+tooltip_func (GtkTooltips   *tooltips,
+	      GtkWidget     *menu,
+	      EggRecentItem *item,
+	      gpointer       user_data)
+{
+	gchar *tip;
+	gchar *uri_for_display;
 
+	uri_for_display = egg_recent_item_get_uri_for_display (item);
+	g_return_if_fail (uri_for_display != NULL);
+	
+	/* Translators: %s is a URI */
+	tip = g_strdup_printf (_("Open '%s'"), uri_for_display);
+
+	g_free (uri_for_display);
+
+	gtk_tooltips_set_tip (tooltips, GTK_WIDGET (menu), tip, NULL);
+
+	g_free (tip);
+}
 
 static void
 gedit_mdi_add_open_button (GeditMDI *mdi, BonoboUIComponent *ui_component,
@@ -280,6 +299,8 @@ gedit_mdi_add_open_button (GeditMDI *mdi, BonoboUIComponent *ui_component,
 			  G_CALLBACK (gedit_file_open_recent), NULL);
 	egg_recent_view_gtk_show_icons (view, TRUE);
 	egg_recent_view_gtk_show_numbers (view, FALSE);
+	egg_recent_view_gtk_set_tooltip_func (view, tooltip_func, NULL);
+	
 	egg_recent_view_set_model (EGG_RECENT_VIEW (view), model);
 	g_object_set_data (G_OBJECT (button), "recent-menu", menu);
 	
@@ -380,6 +401,22 @@ gedit_mdi_new (void)
 	return mdi;
 }
 
+static gchar* 
+tip_func (EggRecentItem *item, gpointer user_data)
+{
+	gchar *tip;
+	gchar *uri_for_display;
+
+	uri_for_display = egg_recent_item_get_uri_for_display (item);
+	g_return_val_if_fail (uri_for_display != NULL, NULL);
+	
+	/* Translators: %s is a URI */
+	tip = g_strdup_printf (_("Open '%s'"), uri_for_display);
+
+	g_free (uri_for_display);
+
+	return tip;
+}
 
 static void
 gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
@@ -409,30 +446,12 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 	g_signal_connect (G_OBJECT (win), "drag_data_received",
 			  G_CALLBACK (gedit_mdi_drag_data_received_handler), 
 			  NULL);
-	
-	/* Add encoding status bar */
-	widget = gtk_statusbar_new ();
-	control = bonobo_control_new (widget);
-	
-	gtk_widget_set_size_request (widget, 180, 10);
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (widget), FALSE);
-
-	bonobo_ui_component_object_set (ui_component,
-		       			"/status/Encoding",
-					BONOBO_OBJREF (control),
-					NULL);
-
-	gtk_widget_show (widget);
-
-	bonobo_object_unref (BONOBO_OBJECT (control));
-
-	g_object_set_data (G_OBJECT (win), "Encoding", widget);
-
+		
 	/* Add cursor position status bar */
 	widget = gtk_statusbar_new ();
 	control = bonobo_control_new (widget);
 	
-	gtk_widget_set_size_request (widget, 150, 10);	
+	gtk_widget_set_size_request (widget, 160, 10);	
 	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (widget), FALSE);
 	
 	bonobo_ui_component_object_set (ui_component,
@@ -510,8 +529,10 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 	view = EGG_RECENT_VIEW (egg_recent_view_bonobo_new (
 					ui_component, "/menu/File/Recents"));
 	egg_recent_view_bonobo_show_icons (EGG_RECENT_VIEW_BONOBO (view), FALSE);
-	egg_recent_view_set_model (view, model);
+	egg_recent_view_bonobo_set_tooltip_func (EGG_RECENT_VIEW_BONOBO (view), tip_func, NULL);
 	
+	egg_recent_view_set_model (view, model);
+
 	g_signal_connect (G_OBJECT (view), "activate",
 			  G_CALLBACK (gedit_file_open_recent), NULL);
 	
@@ -852,7 +873,6 @@ gedit_mdi_child_state_changed_handler (GeditMDIChild *child)
 	gedit_mdi_set_active_window_title (BONOBO_MDI (gedit_mdi));
 	gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
 	gedit_mdi_update_languages_menu (BONOBO_MDI (gedit_mdi));
-	gedit_mdi_update_encoding_status_bar (BONOBO_MDI (gedit_mdi));
 }
 
 static void 
@@ -866,6 +886,17 @@ gedit_mdi_child_undo_redo_state_changed_handler (GeditMDIChild *child)
 	gedit_mdi_set_active_window_undo_redo_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
 }
 
+static void 
+gedit_mdi_child_find_state_changed_handler (GeditMDIChild *child)
+{
+	gedit_debug (DEBUG_MDI, "");
+
+	if (bonobo_mdi_get_active_child (BONOBO_MDI (gedit_mdi)) != BONOBO_MDI_CHILD (child))
+		return;
+	
+	gedit_mdi_set_active_window_find_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
+}
+
 static gint 
 gedit_mdi_add_child_handler (BonoboMDI *mdi, BonoboMDIChild *child)
 {
@@ -877,6 +908,9 @@ gedit_mdi_add_child_handler (BonoboMDI *mdi, BonoboMDIChild *child)
 	g_signal_connect (G_OBJECT (child), "undo_redo_state_changed",
 			  G_CALLBACK (gedit_mdi_child_undo_redo_state_changed_handler), 
 			  NULL);
+	g_signal_connect (G_OBJECT (child), "find_state_changed",
+			  G_CALLBACK (gedit_mdi_child_find_state_changed_handler), 
+			  NULL);
 
 	return TRUE;
 }
@@ -1037,6 +1071,9 @@ gedit_mdi_remove_child_handler (BonoboMDI *mdi, BonoboMDIChild *child)
 		g_signal_handlers_disconnect_by_func (GTK_OBJECT (child), 
 						      G_CALLBACK (gedit_mdi_child_undo_redo_state_changed_handler),
 						      NULL);
+		g_signal_handlers_disconnect_by_func (child, 
+						      G_CALLBACK (gedit_mdi_child_find_state_changed_handler),
+						      NULL);
 	}
 	*/
 	
@@ -1051,48 +1088,6 @@ gedit_mdi_remove_view_handler (BonoboMDI *mdi,  GtkWidget *view)
 	return TRUE;
 }
 
-static void 
-gedit_mdi_update_encoding_status_bar (BonoboMDI *mdi)
-{
-	BonoboMDIChild* active_child = NULL;
-	GeditDocument* doc = NULL;
-	const GeditEncoding* enc;
-	GtkWidget *status;
-	gchar *msg;
-	
-	gedit_debug (DEBUG_MDI, "");
-
-	active_child = bonobo_mdi_get_active_child (mdi);
-	if (active_child == NULL)
-		return;
-
-	doc = GEDIT_MDI_CHILD (active_child)->document;
-	g_return_if_fail (doc != NULL);
-
-	enc = gedit_document_get_encoding (doc);
-
-	status = g_object_get_data (G_OBJECT (bonobo_mdi_get_active_window (mdi)), "Encoding");	
-	g_return_if_fail (status != NULL);
-
-	/* clear any previous message, underflow is allowed */
-	gtk_statusbar_pop (GTK_STATUSBAR (status), 0); 
-
-	if (enc == NULL)
-		msg = g_strdup (_("  Unicode (UTF-8)"));	
-	else
-	{
-		gchar *e = gedit_encoding_to_string (enc);
-
-		msg = g_strdup_printf (_("  %s"), e);
-
-		g_free (e);
-	}
-
-	gtk_statusbar_push (GTK_STATUSBAR (status), 0, msg);
-
-      	g_free (msg);
-}
-
 void 
 gedit_mdi_set_active_window_title (BonoboMDI *mdi)
 {
@@ -1145,7 +1140,6 @@ void gedit_mdi_child_changed_handler (BonoboMDI *mdi, BonoboMDIChild *old_child)
 		
 	gedit_mdi_set_active_window_title (mdi);	
 	gedit_mdi_update_languages_menu (mdi);
-	gedit_mdi_update_encoding_status_bar (mdi);
 }
 
 static 
@@ -1194,14 +1188,6 @@ gedit_mdi_clear_active_window_statusbar (GeditMDI *mdi)
 	if (win == NULL)
 		return;
 
-	status = g_object_get_data (G_OBJECT (win), "Encoding");	
-	g_return_if_fail (status != NULL);
-	g_return_if_fail (GTK_IS_STATUSBAR (status));
-
-	/* clear any previous message, underflow is allowed */
-	gtk_statusbar_pop (GTK_STATUSBAR (status), 0); 
-
-
 	status = g_object_get_data (G_OBJECT (win), "CursorPosition");	
 	g_return_if_fail (status != NULL);
 	g_return_if_fail (GTK_IS_STATUSBAR (status));
@@ -1226,7 +1212,6 @@ gedit_mdi_set_active_window_verbs_sensitivity (BonoboMDI *mdi)
 	BonoboMDIChild* active_child = NULL;
 	GeditDocument* doc = NULL;
 	BonoboUIComponent *ui_component;
-	gchar *lst;
 	
 	gedit_debug (DEBUG_MDI, "");
 	
@@ -1270,10 +1255,11 @@ gedit_mdi_set_active_window_verbs_sensitivity (BonoboMDI *mdi)
 	doc = GEDIT_MDI_CHILD (active_child)->document;
 	g_return_if_fail (doc != NULL);
 	
-	lst = gedit_document_get_last_searched_text (doc);
-
-	gedit_menus_set_verb_sensitive (ui_component, "/commands/SearchFindAgain", lst != NULL);	
-	g_free (lst);
+	if (!gedit_document_can_find_again (doc))
+	{
+		gedit_menus_set_verb_sensitive (ui_component, "/commands/SearchFindNext", FALSE);
+		gedit_menus_set_verb_sensitive (ui_component, "/commands/SearchFindPrev", FALSE);
+	}
 		
 	if (gedit_document_is_readonly (doc))
 	{
@@ -1310,20 +1296,18 @@ static void
 gedit_mdi_set_active_window_undo_redo_verbs_sensitivity (BonoboMDI *mdi)
 {
 	BonoboWindow* active_window = NULL;
-	BonoboMDIChild* active_child = NULL;
 	GeditDocument* doc = NULL;
 	BonoboUIComponent *ui_component;
 	
 	gedit_debug (DEBUG_MDI, "");
 	
-	active_window = bonobo_mdi_get_active_window (mdi);
+	active_window = gedit_get_active_window ();
 	g_return_if_fail (active_window != NULL);
 	
-	ui_component = bonobo_mdi_get_ui_component_from_window (active_window);
+	ui_component = gedit_get_ui_component_from_window (active_window);
 	g_return_if_fail (ui_component != NULL);
 	
-	active_child = bonobo_mdi_get_active_child (mdi);
-	doc = GEDIT_MDI_CHILD (active_child)->document;
+	doc = gedit_get_active_document ();
 	g_return_if_fail (doc != NULL);
 
 	bonobo_ui_component_freeze (ui_component, NULL);
@@ -1337,6 +1321,39 @@ gedit_mdi_set_active_window_undo_redo_verbs_sensitivity (BonoboMDI *mdi)
 	bonobo_ui_component_thaw (ui_component, NULL);
 }
 
+static void 
+gedit_mdi_set_active_window_find_verbs_sensitivity (BonoboMDI *mdi)
+{
+	BonoboWindow* active_window = NULL;
+	GeditDocument* doc = NULL;
+	BonoboUIComponent *ui_component;
+	gboolean sensitive;
+	
+	gedit_debug (DEBUG_MDI, "");
+	
+	active_window = gedit_get_active_window ();
+	g_return_if_fail (active_window != NULL);
+	
+	ui_component = gedit_get_ui_component_from_window (active_window);
+	g_return_if_fail (ui_component != NULL);
+	
+	doc = gedit_get_active_document ();
+	g_return_if_fail (doc != NULL);
+
+	sensitive = gedit_document_can_find_again (doc);
+
+	bonobo_ui_component_freeze (ui_component, NULL);
+
+	gedit_menus_set_verb_sensitive (ui_component, "/commands/SearchFindNext",
+					sensitive);
+
+	gedit_menus_set_verb_sensitive (ui_component, "/commands/SearchFindPrev",
+					sensitive);
+
+	bonobo_ui_component_thaw (ui_component, NULL);
+}
+
+
 EggRecentView *
 gedit_mdi_get_recent_view_from_window (BonoboWindow *win)
 {
@@ -1789,6 +1806,7 @@ add_languages_menu (BonoboMDI *mdi, BonoboWindow *win)
 		g_free (name);
 		g_free (tip);
 		g_free (lang_name);
+		g_free (path);
 
 		l = g_slist_next (l);
 	}		
