@@ -57,8 +57,6 @@
 #define GPM_AUTO_SAVE			GPM_SAVE_DIR "/auto_save"
 #define GPM_AUTO_SAVE_INTERVAL		GPM_SAVE_DIR "/auto_save_interval"
 
-#define GPM_SAVE_ENCODING		GPM_SAVE_DIR "/save_encoding"
-
 #define GPM_UNDO_DIR			GPM_PREFS_DIR  "/editor/undo"
 #define GPM_UNDO_ACTIONS_LIMIT		GPM_UNDO_DIR "/undo_actions_limit"
 
@@ -75,8 +73,10 @@
 #define GPM_LINE_NUMBERS_DIR		GPM_PREFS_DIR "/editor/line_numbers"
 #define GPM_DISPLAY_LINE_NUMBERS 	GPM_LINE_NUMBERS_DIR "/display_line_numbers"
 
-#define GPM_LOAD_DIR			GPM_PREFS_DIR "/editor/load"
-#define GPM_ENCODINGS			GPM_LOAD_DIR "/encodings"
+#define GPM_RIGHT_MARGIN_DIR		GPM_PREFS_DIR "/editor/right_margin"
+#define GPM_DISPLAY_RIGHT_MARGIN	GPM_RIGHT_MARGIN_DIR "/display_right_margin"
+#define GPM_RIGHT_MARGIN_POSITION	GPM_RIGHT_MARGIN_DIR "/right_margin_position"
+
 
 /* UI */
 #define GPM_TOOLBAR_DIR			GPM_PREFS_DIR "/ui/toolbar"
@@ -89,8 +89,9 @@
 #define GRM_RECENTS_DIR			GPM_PREFS_DIR "/ui/recents"
 #define GPM_MAX_RECENTS			GRM_RECENTS_DIR "/max_recents"
 
-/* Print*/
+/* Print */
 #define GPM_PRINT_PAGE_DIR		GPM_PREFS_DIR "/print/page"
+#define GPM_PRINT_SYNTAX		GPM_PRINT_PAGE_DIR "/print_syntax_highlighting"
 #define GPM_PRINT_HEADER		GPM_PRINT_PAGE_DIR "/print_header"
 #define GPM_PRINT_WRAP_MODE		GPM_PRINT_PAGE_DIR "/print_wrap_mode"
 #define GPM_PRINT_LINE_NUMBERS		GPM_PRINT_PAGE_DIR "/print_line_numbers"
@@ -105,6 +106,15 @@
 #define GPM_WINDOW_WIDTH		GPM_WINDOW_DIR "/width"
 #define GPM_WINDOW_HEIGHT		GPM_WINDOW_DIR "/height"
 
+/* Encodings */
+#define GPM_ENCODINGS_DIR		GPM_PREFS_DIR "/encodings"
+#define GPM_AUTO_DETECTED_ENCODINGS	GPM_ENCODINGS_DIR "/auto_detected"
+#define GPM_SHOWN_IN_MENU_ENCODINGS	GPM_ENCODINGS_DIR "/shown_in_menu"
+
+/* Syntax highlighting */
+#define GPM_SYNTAX_HL_DIR		GPM_PREFS_DIR "/syntax_highlighting"
+#define GPM_SYNTAX_HL_ENABLE		GPM_SYNTAX_HL_DIR "/enable"
+
 /* Fallback default values. Keep in sync with gedit.schemas */
 
 #define GPM_DEFAULT_USE_DEFAULT_FONT 	0 /* FALSE */
@@ -135,7 +145,7 @@
 
 #define GPM_DEFAULT_DISPLAY_LINE_NUMBERS 0 /* FALSE */
 
-#define GPM_DEFAULT_ENCODINGS		{"ISO-8859-15", NULL}
+#define GPM_DEFAULT_AUTO_DETECTED_ENCODINGS {"UTF-8", "CURRENT", "ISO-8859-15", NULL}
        	
 #define GPM_DEFAULT_TOOLBAR_VISIBLE	1 /* TRUE */
 #define GPM_DEFAULT_TOOLBAR_BUTTONS_STYLE "GEDIT_TOOLBAR_SYSTEM"
@@ -143,8 +153,9 @@
 
 #define GPM_DEFAULT_STATUSBAR_VISIBLE	1 /* TRUE */
 
+#define GPM_DEFAULT_PRINT_SYNTAX	1 /* TRUE */
 #define GPM_DEFAULT_PRINT_HEADER	1 /* TRUE */
-#define GPM_DEFAULT_PRINT_WRAP_MODE	"GTK_WRAP_CHAR"
+#define GPM_DEFAULT_PRINT_WRAP_MODE	"GTK_WRAP_WORD"
 #define GPM_DEFAULT_PRINT_LINE_NUMBERS	0 /* No numbers */
 
 #define GPM_DEFAULT_PRINT_FONT_BODY 	(const gchar*) "Monospace Regular 9"
@@ -161,6 +172,10 @@
 #define GPM_DEFAULT_WINDOW_WIDTH_STR	"650"
 #define GPM_DEFAULT_WINDOW_HEIGHT_STR	"500"
 
+#define GPM_DEFAULT_DISPLAY_RIGHT_MARGIN  0 /* FALSE */
+#define GPM_DEFAULT_RIGHT_MARGIN_POSITION 80
+
+#define GPM_DEFAULT_SYNTAX_HL_ENABLE	1 /* TRUE */
 
 typedef enum {
 	GEDIT_TOOLBAR_SYSTEM = 0,
@@ -169,13 +184,6 @@ typedef enum {
 	GEDIT_TOOLBAR_ICONS_BOTH_HORIZ
 } GeditToolbarSetting;
 
-typedef enum {
-	GEDIT_SAVE_ALWAYS_UTF8 = 0,
-	GEDIT_SAVE_CURRENT_LOCALE_IF_POSSIBLE,
-	GEDIT_SAVE_ORIGINAL_FILE_ENCODING_IF_POSSIBLE,
-	GEDIT_SAVE_ORIGINAL_FILE_ENCODING_IF_POSSIBLE_NCL
-} GeditSaveEncodingSetting;
-
 /** LIFE CYCLE MANAGEMENT FUNCTIONS **/
 
 gboolean		 gedit_prefs_manager_init (void);
@@ -239,11 +247,6 @@ gint			 gedit_prefs_manager_get_auto_save_interval	(void);
 void			 gedit_prefs_manager_set_auto_save_interval	(gint asi);
 gboolean		 gedit_prefs_manager_auto_save_interval_can_set	(void);
 
-/* Save encoding */
-GeditSaveEncodingSetting gedit_prefs_manager_get_save_encoding		(void);
-void			 gedit_prefs_manager_set_save_encoding		(GeditSaveEncodingSetting se);
-gboolean 		 gedit_prefs_manager_save_encoding_can_set	(void);
-
 /* Undo actions limit: if < 1 then no limits */
 gint 			 gedit_prefs_manager_get_undo_actions_limit	(void);
 void			 gedit_prefs_manager_set_undo_actions_limit	(gint ual);
@@ -290,6 +293,11 @@ gboolean		 gedit_prefs_manager_get_statusbar_visible	(void);
 void			 gedit_prefs_manager_set_statusbar_visible	(gboolean sv);
 gboolean		 gedit_prefs_manager_statusbar_visible_can_set	(void);
 
+/* Print syntax highlighting */
+gboolean		 gedit_prefs_manager_get_print_syntax_hl	(void);
+void			 gedit_prefs_manager_set_print_syntax_hl	(gboolean ps);
+gboolean		 gedit_prefs_manager_print_syntax_hl_can_set	(void);
+
 /* Print header */
 gboolean		 gedit_prefs_manager_get_print_header		(void);
 void			 gedit_prefs_manager_set_print_header		(gboolean ph);
@@ -329,9 +337,26 @@ const gchar		*gedit_prefs_manager_get_default_print_font_numbers (void);
 gint		 	 gedit_prefs_manager_get_max_recents		(void);
 
 /* Encodings */
-GSList 			*gedit_prefs_manager_get_encodings		(void);
-void			 gedit_prefs_manager_set_encodings		(const GSList *encs);
-gboolean 		 gedit_prefs_manager_encodings_can_set		(void);
+GSList 			*gedit_prefs_manager_get_auto_detected_encodings (void);
+
+GSList			*gedit_prefs_manager_get_shown_in_menu_encodings (void);
+void			 gedit_prefs_manager_set_shown_in_menu_encodings (const GSList *encs);
+gboolean 		 gedit_prefs_manager_shown_in_menu_encodings_can_set (void);
+
+/* Display right margin */
+gboolean		 gedit_prefs_manager_get_display_right_margin	(void);
+void			 gedit_prefs_manager_set_display_right_margin	(gboolean drm);
+gboolean		 gedit_prefs_manager_display_right_margin_can_set (void);
+
+/* Right margin position */
+gint		 	 gedit_prefs_manager_get_right_margin_position	(void);
+void 			 gedit_prefs_manager_set_right_margin_position	(gint rmp);
+gboolean		 gedit_prefs_manager_right_margin_position_can_set (void);
+
+/* Enable syntax highlighting */
+gboolean 		 gedit_prefs_manager_get_enable_syntax_highlighting (void);
+void			 gedit_prefs_manager_set_enable_syntax_highlighting (gboolean esh);
+gboolean		 gedit_prefs_manager_enable_syntax_highlighting_can_set (void);
 
 #endif  /* __GEDIT_PREFS_MANAGER_H__ */
 
